"use client";
import Image from "next/image";
import Link from "next/link";
import React, { useState } from "react";
import { EvaluatorProfileTab } from "@/components/modules/SellerProfile/EvaluatorProfileTab";
import { MyProfileTab } from "@/components/modules/SellerProfile/MyProfileTab";
import MyListingTab from "@/components/modules/SellerProfile/MyListingTab";
import { ProtocolTab } from "@/components/modules/SellerProfile/ProtocolTab";
import { ElectronicTab } from "@/components/modules/SellerProfile/ElectronicTab";
import { DocumentTab } from "@/components/modules/SellerProfile/DocumentTab";
import { SaleTab } from "@/components/modules/SellerProfile/SaleTab";
import { PropertyEvaluationTab } from "@/components/modules/SellerProfile/PropertyEvaluationTab";
import { CarsEvaluationTab } from "@/components/modules/SellerProfile/CarsEvaluationTab";
import { BoatEvaluationTab } from "@/components/modules/SellerProfile/BoatEvaluationTab";
import { JewelleryEvaluationTab } from "@/components/modules/SellerProfile/JewelleryEvaluation";
import {
  PrimaryProtocol,
  PrimaryLogout,
  PrimarySale,
  PrimaryDocument,
  PrimaryAssetDocument,
  DropIcon,
  PrimaryPassword,
  PrimaryTickTok,
  PrimaryFacebook,
  PrimaryInsta,
  PrimarySecurity,
  PrimaryProfile,
  PrimaryListing,
  PrimaryElectronic,
  PrimaryTwitter,
  PrimaryLinkdIn,
} from "@/components/Icons";
import { EvaluationTab } from "@/components/modules/SellerProfile/EvaluationTab";
import man from "@/assets/images/seller-profile-02.png";

export default function Electronic() {
  const [selectedTabIdx, setSelectedTabIdx] = useState(3);
  const [isDropdownOpen, setIsDropdownOpen] = useState(false);

  const handleDropdownToggle = () => {
    setIsDropdownOpen(!isDropdownOpen);
  };

  const tabs = [
    {
      icon: <PrimaryProfile />,
      name: "Evaluator Profile",
      link: "/seller-profile",
    },
    { icon: <PrimaryProfile />, name: "My Profile", link: "/seller-profile" },
    {
      icon: <PrimaryListing />,
      name: "My Listing",
      link: "/seller-profile/my-listing",
    },
    {
      icon: <PrimaryProtocol />,
      name: "Confidentiality and Protocol",
      link: "/seller-profile/confidentiality-protocol",
    },
    {
      icon: <PrimaryElectronic />,
      name: "Electronic Consent",
      link: "/seller-profile/electronic-consent",
    },
    {
      icon: <PrimaryAssetDocument />,
      name: "Asset Evaluation",
      link: "#",
      dropdown: [
        {
          name: "Property Evaluation",
          link: "/seller-profile/property-evaluation",
        },
        { name: "Cars Evaluation", link: "/seller-profile/cars-evaluation" },
        { name: "Boat Evaluation", link: "/seller-profile/boat-evaluation" },
        {
          name: "Jewellery Evaluation",
          link: "/seller-profile/jewellery-evaluation",
        },
      ],
    },
    {
      icon: <PrimaryDocument />,
      name: "Documents Storage",
      link: "/seller-profile/documents-storage",
    },
    {
      icon: <PrimarySale />,
      name: "Sale Tracker",
      link: "/seller-profile/sale-tracker",
    },
    {
      icon: <PrimarySecurity />,
      name: "Security",
      link: "/seller-profile/security",
    },
    {
      icon: <PrimaryPassword />,
      name: "Change Password",
      link: "/seller-profile/change-password",
    },
    { icon: <PrimaryLogout />, name: "Sign Out", link: "#" },
  ];

  return (
    <div className="theme-container !py-8 flex flex-col md:flex-row gap-7">
      <div className="flex flex-col gap-7 m:min-w-[385px]">
        <div className="custom-shadow flex justify-center items-center flex-col py-6 rounded">
          <figure className="bg-whiteSmoke  rounded-full h-[184px] w-[184px] ">
            <Image
              src='/assets/images/Group 192.png'
              alt="Profile"
              height={184}
              width={184}
              className="mb-5 rounded-full bottom-0"
            />
          </figure>
          <h1 className="text-prussianBlue font-semibold text-3xl">
            Fahad Ahmad
          </h1>
          <h2 className="text-2xl text-prussianBlue mb-3">Asset Holder</h2>
          <div className="flex gap-3">
            <Link href="#">
              <PrimaryFacebook className="h-[17px] w-[17px]" />
            </Link>
            <Link href="#">
              <PrimaryInsta className="h-[17px] w-[17px]" />
            </Link>
            <Link href="#">
              <PrimaryLinkdIn className="h-[17px] w-[17px]" />
            </Link>
            <Link href="#">
              <PrimaryTwitter className="h-[17px] w-[17px]" />
            </Link>
            <Link href="#">
              <PrimaryTickTok className="h-[17px] w-[17px]" />
            </Link>
          </div>
        </div>
        <div className="flex flex-col custom-shadow rounded py-5">
          <div>
            <nav className="flex flex-col" aria-label="Tabs">
              {tabs.map((tab, i) =>
                tab.dropdown ? (
                  <div key={tab.name} className="relative">
                    <div
                      className={`${
                        i === selectedTabIdx
                          ? "bg-whiteSmoke font-medium  focus:outline-none"
                          : "border-transparent"
                      } whitespace-nowrap flex gap-3 hover:bg-whiteSmoke hover:text-prussianBlue items-center py-2 px-8 cursor-pointer sm:text-xl`}
                      onClick={() => {
                        setSelectedTabIdx(i);
                        handleDropdownToggle();
                      }}
                    >
                      {tab.icon}
                      {tab.name}
                      <span className="ml-auto">
                        <DropIcon />
                      </span>
                    </div>
                    {isDropdownOpen && (
                      <div className="bg-whiteSmoke rounded-md ">
                        {tab.dropdown.map((item, idx) => (
                          <Link
                            key={idx}
                            href={item.link}
                            className="block py-2 px-14  text-black  hover:bg-white cursor-pointer"
                          >
                            {item.name}
                          </Link>
                        ))}
                      </div>
                    )}
                  </div>
                ) : (
                  <Link
                    href={tab.link}
                    key={tab.name}
                    className={`${
                      i === selectedTabIdx
                        ? "bg-whiteSmoke text-prussianBlue font-medium focus:outline-none"
                        : "border-transparent"
                    } whitespace-nowrap flex gap-3 hover:bg-whiteSmoke hover:text-prussianBlue items-center py-2 px-8 cursor-pointer sm:text-xl`}
                    onClick={() => setSelectedTabIdx(i)}
                  >
                    {tab.icon}
                    {tab.name}
                  </Link>
                )
              )}
            </nav>
          </div>
        </div>
      </div>
      <div className="grow">
        {selectedTabIdx === 0 && <EvaluatorProfileTab activeTab={0} />}
        {selectedTabIdx === 0 && <MyProfileTab activeTab={1} />}
        {selectedTabIdx === 2 && <MyListingTab />}
        {selectedTabIdx === 3 && <ProtocolTab />}
        {selectedTabIdx === 4 && <ElectronicTab />}
        {selectedTabIdx === 5 && <EvaluationTab />}
        {selectedTabIdx === 6 && <PropertyEvaluationTab />}
        {selectedTabIdx === 7 && <CarsEvaluationTab />}
        {selectedTabIdx === 8 && <BoatEvaluationTab />}
        {selectedTabIdx === 9 && <JewelleryEvaluationTab />}
        {selectedTabIdx === 10 && <DocumentTab />}
        {selectedTabIdx === 11 && <SaleTab />}
        {selectedTabIdx === 12 && <MyProfileTab activeTab={2} />}
        {selectedTabIdx === 13 && <MyProfileTab activeTab={3} />}
      </div>
    </div>
  );
}
